/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.model;

import junit.framework.TestCase;

public class SentencePartitionListTest extends TestCase {

	public void testSize() {
		try {
			new SentencePartitionList(null);
			fail();
		} catch (final NullPointerException e) {
			assertTrue(true);
		}
		assertEquals(1, new SentencePartitionList("").size());
		assertEquals(1, new SentencePartitionList("test").size());
		assertEquals(1, new SentencePartitionList(" test ").size());

		assertEquals(1, new SentencePartitionList("test.text").size());
		assertEquals(2, new SentencePartitionList("test. text").size());
		assertEquals(2, new SentencePartitionList(" test. text ").size());
		assertEquals(2, new SentencePartitionList(" test.  text ").size());
		assertEquals(2, new SentencePartitionList(" test.\rtext ").size());
		assertEquals(2, new SentencePartitionList(" test.\r\ntext ").size());
		assertEquals(2, new SentencePartitionList(" test.\r\n\ttext ").size());
		assertEquals(3, new SentencePartitionList(" test text. test text. test text.").size());

		assertEquals(2, new SentencePartitionList("test.&nbsp;text").size());
		assertEquals(2, new SentencePartitionList("test. &nbsp;text").size());
		assertEquals(2, new SentencePartitionList("test. &nbsp; text").size());

		assertEquals(1, new SentencePartitionList("test?text").size());
		assertEquals(2, new SentencePartitionList("test? text").size());
		assertEquals(2, new SentencePartitionList("test?  text").size());

		assertEquals(1, new SentencePartitionList("test!text").size());
		assertEquals(2, new SentencePartitionList("test! text").size());
		assertEquals(2, new SentencePartitionList("test!  text").size());

		assertEquals(1, new SentencePartitionList("test:text").size());
		assertEquals(2, new SentencePartitionList("test: text").size());
		assertEquals(2, new SentencePartitionList(" test: text ").size());
		assertEquals(2, new SentencePartitionList(" test:  text ").size());
		assertEquals(2, new SentencePartitionList(" test:\rtext ").size());
		assertEquals(2, new SentencePartitionList(" test:\r\ntext ").size());
		assertEquals(2, new SentencePartitionList(" test:\r\n\ttext ").size());
		assertEquals(3, new SentencePartitionList(" test text: test text: test text:").size());

		assertEquals(2, new SentencePartitionList("test. text.").size());
		assertEquals(2, new SentencePartitionList("<test>. text.").size());
		assertEquals(2, new SentencePartitionList("<test. text.>").size());
		assertEquals(2, new SentencePartitionList("(test). text.").size());
		assertEquals(2, new SentencePartitionList("(test. text.)").size());

		assertEquals(1, new SentencePartitionList("<a>test</a> text.").size());
		assertEquals(2, new SentencePartitionList("<a>test. text.</a>").size());
		assertEquals(2, new SentencePartitionList("<a>test</a>: abc").size());
		assertEquals(1, new SentencePartitionList("<a href=\"a\">test</a> text.").size());
		assertEquals(2, new SentencePartitionList("<a href=\"a\">test. text.</a>").size());
		assertEquals(2, new SentencePartitionList("<a href=\"a\">test</a>: abc").size());

		assertEquals(1, new SentencePartitionList("<i>test.</i> text.").size());
		assertEquals(1, new SentencePartitionList("<font size=\"1\">test.</font> text.").size());
	}
}
