/*
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package benten.twa.tmx.messages;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * TMXマージ機能のためのメッセージ。
 *
 * リソースバンドル定義: [BentenMergeTmxMessages]。<BR>
 * このクラスはリソースバンドル定義書から自動生成されたリソースバンドルクラスです。<BR>
 * 既知のロケール<BR>
 * <UL>
 * <LI>en
 * <LI>ja
 * </UL>
 */
public class BentenMergeTmxMessages {
    /**
     * リソースバンドルオブジェクト。
     *
     * 内部的に実際に入力を行うリソースバンドルを記憶します。
     */
    private ResourceBundle fResourceBundle;

    /**
     * BentenMergeTmxMessagesクラスのコンストラクタ。
     *
     * 基底名[BentenMergeTmxMessages]、デフォルトのロケール、呼び出し側のクラスローダを使用して、リソースバンドルを取得します。
     */
    public BentenMergeTmxMessages() {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/twa/tmx/messages/BentenMergeTmxMessages");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BentenMergeTmxMessagesクラスのコンストラクタ。
     *
     * 基底名[BentenMergeTmxMessages]、指定されたロケール、呼び出し側のクラスローダを使用して、リソースバンドルを取得します。
     *
     * @param locale ロケールの指定
     */
    public BentenMergeTmxMessages(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/twa/tmx/messages/BentenMergeTmxMessages", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BentenMergeTmxMessagesクラスのコンストラクタ。
     *
     * 基底名[BentenMergeTmxMessages]、指定されたロケール、指定されたクラスローダを使用して、リソースバンドルを取得します。
     *
     * @param locale ロケールの指定
     * @param loader クラスローダの指定
     */
    public BentenMergeTmxMessages(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/twa/tmx/messages/BentenMergeTmxMessages", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * 内部的に保持しているリソースバンドルオブジェクトを取得します。
     *
     * @return 内部的に保持しているリソースバンドルオブジェクト。
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WindowTitle]
     *
     * [TMX フラグメントのマージ] (en)<br>
     * [TMX フラグメントのマージ] (ja)<br>
     *
     * @return key[WindowTitle]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWindowTitle() {
        // 初期値として定義書の値を利用します。
        String strFormat = "TMX フラグメントのマージ";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WindowTitle");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[JobName]
     *
     * [TMX フラグメントのマージ中...] (en)<br>
     * [TMX フラグメントのマージ中...] (ja)<br>
     *
     * @return key[JobName]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getJobName() {
        // 初期値として定義書の値を利用します。
        String strFormat = "TMX フラグメントのマージ中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("JobName");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WizardPageTitle]
     *
     * [ようこそ] (en)<br>
     * [ようこそ] (ja)<br>
     *
     * @return key[WizardPageTitle]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWizardPageTitle() {
        // 初期値として定義書の値を利用します。
        String strFormat = "ようこそ";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WizardPageTitle");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WizardPageDescription]
     *
     * [TMX フラグメントを TMX にマージします。] (en)<br>
     * [TMX フラグメントを TMX にマージします。] (ja)<br>
     *
     * @return key[WizardPageDescription]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWizardPageDescription() {
        // 初期値として定義書の値を利用します。
        String strFormat = "TMX フラグメントを TMX にマージします。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WizardPageDescription");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WizardPageLabel1]
     *
     * [このウィザードは、TMX フラグメントを TMX にマージします。\n\n 1.  TMX の内容を、別の TMX にマージします。] (en)<br>
     * [このウィザードは、TMX フラグメントを TMX にマージします。\n\n 1.  TMX の内容を、別の TMX にマージします。] (ja)<br>
     *
     * @return key[WizardPageLabel1]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWizardPageLabel1() {
        // 初期値として定義書の値を利用します。
        String strFormat = "このウィザードは、TMX フラグメントを TMX にマージします。\n\n 1.  TMX の内容を、別の TMX にマージします。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WizardPageLabel1");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WizardPage2Title]
     *
     * [対象ファイルの指定] (en)<br>
     * [対象ファイルの指定] (ja)<br>
     *
     * @return key[WizardPage2Title]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWizardPage2Title() {
        // 初期値として定義書の値を利用します。
        String strFormat = "対象ファイルの指定";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WizardPage2Title");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WizardPage2Description]
     *
     * [対象ファイルを指定します。] (en)<br>
     * [対象ファイルを指定します。] (ja)<br>
     *
     * @return key[WizardPage2Description]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWizardPage2Description() {
        // 初期値として定義書の値を利用します。
        String strFormat = "対象ファイルを指定します。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WizardPage2Description");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[WizardPage3ResultMessage]
     *
     * [TMX のマージが完了しました。] (en)<br>
     * [TMX のマージが完了しました。] (ja)<br>
     *
     * @return key[WizardPage3ResultMessage]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getWizardPage3ResultMessage() {
        // 初期値として定義書の値を利用します。
        String strFormat = "TMX のマージが完了しました。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("WizardPage3ResultMessage");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[DialogCtrlLabelFromFile]
     *
     * [マージ元] (en)<br>
     * [マージ元] (ja)<br>
     *
     * @return key[DialogCtrlLabelFromFile]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getDialogCtrlLabelFromFile() {
        // 初期値として定義書の値を利用します。
        String strFormat = "マージ元";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("DialogCtrlLabelFromFile");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[DialogCtrlLabelToFile]
     *
     * [マージ先] (en)<br>
     * [マージ先] (ja)<br>
     *
     * @return key[DialogCtrlLabelToFile]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getDialogCtrlLabelToFile() {
        // 初期値として定義書の値を利用します。
        String strFormat = "マージ先";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("DialogCtrlLabelToFile");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP001]
     *
     * [処理内容を計画中...] (en)<br>
     * [処理内容を計画中...] (ja)<br>
     *
     * @return key[CoreP001]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP001() {
        // 初期値として定義書の値を利用します。
        String strFormat = "処理内容を計画中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP001");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP003]
     *
     * [処理を完了しました。\n{0}] (en)<br>
     * [処理を完了しました。\n{0}] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreP003]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP003(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "処理を完了しました。\n{0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP003");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP011]
     *
     * [入力ファイル [{0}] を読み込み処理中...] (en)<br>
     * [入力ファイル [{0}] を読み込み処理中...] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreP011]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP011(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "入力ファイル [{0}] を読み込み処理中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP011");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP012]
     *
     * [出力ファイル [{0}] を読み込み処理中...] (en)<br>
     * [出力ファイル [{0}] を読み込み処理中...] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreP012]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP012(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "出力ファイル [{0}] を読み込み処理中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP012");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP013]
     *
     * [マップを作成中...] (en)<br>
     * [マップを作成中...] (ja)<br>
     *
     * @return key[CoreP013]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP013() {
        // 初期値として定義書の値を利用します。
        String strFormat = "マップを作成中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP013");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP014]
     *
     * [マップから引き当て中...] (en)<br>
     * [マップから引き当て中...] (ja)<br>
     *
     * @return key[CoreP014]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP014() {
        // 初期値として定義書の値を利用します。
        String strFormat = "マップから引き当て中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP014");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP015]
     *
     * [TMX をソート中...] (en)<br>
     * [TMX をソート中...] (ja)<br>
     *
     * @return key[CoreP015]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP015() {
        // 初期値として定義書の値を利用します。
        String strFormat = "TMX をソート中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP015");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreP016]
     *
     * [TMX ファイル [{0}] を処理中...] (en)<br>
     * [TMX ファイル [{0}] を処理中...] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreP016]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreP016(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "TMX ファイル [{0}] を処理中...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreP016");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE011]
     *
     * [入力 TMX ファイル [{0}] は見つかりませんでした。] (en)<br>
     * [入力 TMX ファイル [{0}] は見つかりませんでした。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE011]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE011(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "入力 TMX ファイル [{0}] は見つかりませんでした。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE011");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE012]
     *
     * [入力 TMX ファイル [{0}] は、ファイルではありません。] (en)<br>
     * [入力 TMX ファイル [{0}] は、ファイルではありません。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE012]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE012(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "入力 TMX ファイル [{0}] は、ファイルではありません。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE012");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE013]
     *
     * [入力 TMX ファイル [{0}] は、読み込めません。] (en)<br>
     * [入力 TMX ファイル [{0}] は、読み込めません。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE013]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE013(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "入力 TMX ファイル [{0}] は、読み込めません。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE013");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE014]
     *
     * [出力 TMX ファイル [{0}] は見つかりませんでした。] (en)<br>
     * [出力 TMX ファイル [{0}] は見つかりませんでした。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE014]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE014(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "出力 TMX ファイル [{0}] は見つかりませんでした。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE014");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE015]
     *
     * [出力 TMX ファイル [{0}] は、ファイルではありません。] (en)<br>
     * [出力 TMX ファイル [{0}] は、ファイルではありません。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE015]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE015(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "出力 TMX ファイル [{0}] は、ファイルではありません。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE015");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE016]
     *
     * [出力 TMX ファイル [{0}] は、読み込めません。] (en)<br>
     * [出力 TMX ファイル [{0}] は、読み込めません。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE016]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE016(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "出力 TMX ファイル [{0}] は、読み込めません。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE016");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE017]
     *
     * [出力 TMX ファイル [{0}] は、書き込めません。] (en)<br>
     * [出力 TMX ファイル [{0}] は、書き込めません。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE017]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE017(final String arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "出力 TMX ファイル [{0}] は、書き込めません。";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE017");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BentenMergeTmxMessages], key[CoreE022]
     *
     * [出力 TMX ファイル [{0}] の書き込み中に例外が発生しました。: {1}] (en)<br>
     * [出力 TMX ファイル [{0}] の書き込み中に例外が発生しました。: {1}] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.lang.String型を与えてください。
     * @param arg1 置換文字列{1}を置換する値。java.lang.String型を与えてください。
     * @return key[CoreE022]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCoreE022(final String arg0, final String arg1) {
        // 初期値として定義書の値を利用します。
        String strFormat = "出力 TMX ファイル [{0}] の書き込み中に例外が発生しました。: {1}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CoreE022");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }
}
